@@ -3,10 +3,10 @@ context("loadobj")
 test_that("can load an obj file", {
   expect_error(read.obj(c("foo","bar")), "single")
   expect_error(read.obj("rhubarb"), "Cannot open file")
-  expect_warning(read.obj(system.file("obj/cube_badmtl.obj", package = "readobj")),
+  expect_warning(read.obj(system.file("obj/cube_badmtl.wavefront", package = "readobj")),
                  'default material')
 
-  expect_is(cube<-read.obj(system.file("obj/cube.obj", package = "readobj")),
+  expect_is(cube<-read.obj(system.file("obj/cube.wavefront", package = "readobj")),
             "list")
   # saveRDS(cube, file='tests/testthat/testdata/cube.rds')
   cube_baseline=readRDS("testdata/cube.rds")
